@@ -212,7 +212,7 @@ class SqleeColumn:
             ))
 
         for data in self.datas:
-            setattr(self, self.namespace[datas.index(data)], data)
+            setattr(self, self.namespace[self.datas.index(data)], data)
 
         if len(self.datas) != len(self.namespace):
             print(ColumnDataDoesNotFit(namespace=self.namespace, datas=self.datas))
